import Airtable from 'airtable';
import { useState, useEffect } from 'react';

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
}

function _iterableToArrayLimit(arr, i) {
  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var useAirtable = function useAirtable(tableName, apiKey, baseId) {
  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      records = _useState2[0],
      setRecords = _useState2[1];

  var base = new Airtable({
    apiKey: apiKey
  }).base(baseId);

  var getRecords = function getRecords() {
    base('Tasks').select({
      view: 'Grid view'
    }).eachPage(function page(fetchedRecords, fetchNextPage) {
      // This function (`page`) will get called for each page of records.
      setRecords([].concat(_toConsumableArray(records), _toConsumableArray(fetchedRecords)));
      fetchNextPage();
    }, function done(err) {
      if (err) {
        console.error(err);
      }
    });
  };

  useEffect(function () {
    getRecords();
  }, []);

  var createRecord = function createRecord(fields) {
    return new Promise(function (resolve, reject) {
      base(tableName).create(fields, function (err, record) {
        if (err) {
          reject(err);
          return;
        } // on successful request -> update records state


        setRecords([].concat(_toConsumableArray(records), [record]));
        resolve(record);
      });
    });
  };

  var updateRecord = function updateRecord(recordId, fields) {
    return new Promise(function (resolve, reject) {
      base('Tasks').update([{
        id: recordId,
        fields: fields
      }], function (err, updatedRecords) {
        if (err) {
          reject(err);
          return;
        }

        updatedRecords.forEach(function (updatedRecord) {
          // on successful request -> update records state
          setRecords(records.map(function (record) {
            return record.id === recordId ? updatedRecord : record;
          }));
          resolve(updatedRecord);
        });
      });
    });
  };

  var deleteRecord = function deleteRecord(recordId) {
    return new Promise(function (resolve, reject) {
      base('Tasks').destroy(recordId, function (err, deletedRecord) {
        if (err) {
          reject(err);
          return;
        } // on successful request -> update records state


        setRecords(records.filter(function (record) {
          return record.id !== recordId;
        }));
        resolve();
      });
    });
  };

  return [records, createRecord, updateRecord, deleteRecord];
};

export { useAirtable };
//# sourceMappingURL=index.es.js.map
